Talairach atlas

Content
-------
    :'maps': 3D Nifti image, values are integers corresponding to indices in the
             list of labels.

    :'labels': Annotations ({})

References
----------
http://talairach.org/about.html#Labels

`Lancaster JL, Woldorff MG, Parsons LM, Liotti M, Freitas CS, Rainey L, Kochunov
PV, Nickerson D, Mikiten SA, Fox PT, "Automated Talairach Atlas labels for
functional brain mapping". Human Brain Mapping 10:120-131, 2000.`

`Lancaster JL, Rainey LH, Summerlin JL, Freitas CS, Fox PT, Evans AC, Toga AW,
Mazziotta JC. Automated labeling of the human brain: A preliminary report on the
development and evaluation of a forward-transform method. Hum Brain Mapp 5,
238-242, 1997.`
